@@ -650,25 +650,35 @@ int main(int argc, char *argv[])
 {
 	l_test_init(&argc, &argv);
 
-	l_test_add("unsupported", test_unsupported, NULL);
+	l_test_add_func("unsupported", test_unsupported, 0);
 
-	l_test_add("user key", test_user, NULL);
+	l_test_add_func("user key", test_user, 0);
 
 	if (l_key_is_supported(L_KEY_FEATURE_DH)) {
-		l_test_add("Diffie-Hellman 1", test_dh, &dh_valid1);
-		l_test_add("Diffie-Hellman 2", test_dh, &dh_valid2);
-		l_test_add("Diffie-Hellman 3", test_dh, &dh_degenerate);
+		l_test_add_data_func("Diffie-Hellman 1",
+						&dh_valid1, test_dh,
+						L_TEST_FLAG_ALLOW_FAILURE);
+		l_test_add_data_func("Diffie-Hellman 2",
+						&dh_valid2, test_dh,
+						L_TEST_FLAG_ALLOW_FAILURE);
+		l_test_add_data_func("Diffie-Hellman 3",
+						&dh_degenerate, test_dh,
+						L_TEST_FLAG_ALLOW_FAILURE);
 	}
 
-	l_test_add("simple keyring", test_simple_keyring, NULL);
+	l_test_add_func("simple keyring", test_simple_keyring,
+						L_TEST_FLAG_ALLOW_FAILURE);
 
 	if (l_key_is_supported(L_KEY_FEATURE_RESTRICT)) {
-		l_test_add("trusted keyring", test_trusted_keyring, NULL);
-		l_test_add("trust chain", test_trust_chain, NULL);
+		l_test_add_func("trusted keyring", test_trusted_keyring,
+						L_TEST_FLAG_ALLOW_FAILURE);
+		l_test_add_func("trust chain", test_trust_chain,
+						L_TEST_FLAG_ALLOW_FAILURE);
 	}
 
 	if (l_key_is_supported(L_KEY_FEATURE_CRYPTO))
-		l_test_add("key crypto", test_key_crypto, NULL);
+		l_test_add_func("key crypto", test_key_crypto,
+						L_TEST_FLAG_ALLOW_FAILURE);
 
 	return l_test_run();
 }
